==> centreon-web-25.10.0.tar.gz: centreon-web-25.10.0/src/Core/Installation/Infrastructure/InstallationHelper.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Installation\Infrastructure;

use Core\Engine\Application\Repository\EngineRepositoryInterface;
use Core\Engine\Domain\Model\EngineKey;
use Core\Engine\Domain\Model\EngineSecrets;
use Security\Interfaces\EncryptionInterface;

final readonly class InstallationHelper
{
    public function __construct(
        private EngineRepositoryInterface $engineRepository,
        private EncryptionInterface $encryption,
        private string $appSecret
    ) {
    }

    /**
     * Write Engine Secrets content in EngineContext File.
     */
    public function writeEngineContextFile(): void
    {
        $engineSecrets = new EngineSecrets(
            firstKey: new EngineKey($this->appSecret),
            secondKey: new EngineKey($this->encryption->generateRandomString())
        );

        $this->engineRepository->writeEngineSecrets($engineSecrets);
    }
}

==> centreon-web-25.10.6.tar.gz: centreon-web-25.10.6/src/Core/Installation/Infrastructure/InstallationHelper.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Installation\Infrastructure;

use Core\Engine\Application\Repository\EngineRepositoryInterface;
use Core\Engine\Domain\Model\EngineKey;
use Core\Engine\Domain\Model\EngineSecrets;
use Security\Interfaces\EncryptionInterface;

final readonly class InstallationHelper
{
    public function __construct(
        private EngineRepositoryInterface $engineRepository,
        private EncryptionInterface $encryption,
        private string $appSecret,
    ) {
    }

    /**
     * Write Engine Secrets content in EngineContext File.
     */
    public function writeEngineContextFile(): void
    {
        $engineSecrets = new EngineSecrets(
            firstKey: new EngineKey($this->appSecret),
            secondKey: new EngineKey($this->encryption->generateRandomString())
        );

        $this->engineRepository->writeEngineSecrets($engineSecrets);
    }
}
